Every object that is not a character, from OBJECT_INDEX (OBJECT_INDEX). Size and weight are bytes 2 and 3 of the record, strength and defence bytes 5 and 6 (see DO_ATTACK, DO_ATTACK); the flags are byte 7. Handlers are the object's own, which DO_ACTION (DO_ACTION) asks before the ordinary one.

No.ObjectStartsSizeWeightStrDefFlagsOwn handlers
$01heavy rock doortrolls cave, trolls path2552550144present, lockedSTRIKE WITH: DO_STRIKE
CLOSE: DO_CLOSE
OPEN: DO_OPEN
LOOK THROUGH: LOOK_THROUGH
GO THROUGH: GO_THROUGH
LOCK WITH: ROCK_DOOR_KEY
UNLOCK WITH: ROCK_DOOR_KEY
THROW THROUGH: THROW_THROUGH
$02small curious keygoblins dungeon, held by goblins cache0000presentnone
$03curious map
tunnel like hall, held by gandalf2002presentEXAMINE: ELROND_READS_MAP
$04large keytrolls clearing, held by hideous troll1100presentnone
$05round green doortunnel like hall, lonelands255255016presentSTRIKE WITH: DO_STRIKE
CLOSE: DO_CLOSE
OPEN: DO_OPEN
LOOK THROUGH: LOOK_THROUGH
GO THROUGH: GO_THROUGH
LOCK WITH: NO_KEY_FITS
UNLOCK WITH: NO_KEY_FITS
THROW THROUGH: THROW_THROUGH
$06small insignificant cracklarge dry cave, dark stuffy passage2552552550presentOPEN: OPEN_CRACK
CLOSE: DO_CLOSE
GO THROUGH: GO_THROUGH
LOOK THROUGH: LOOK_THROUGH
$07spider webspider threads place, levelled elvish clearing, smothering forest, deep bog, green forest160806464presentSTRIKE WITH: DO_STRIKE
after STRIKE WITH: WEB_BROKEN
GO THROUGH: GO_THROUGH
$08red doordark dungeon, elvenkings great halls, elvenkings cellar25525500present, lockedOPEN: DO_OPEN
CLOSE: DO_CLOSE
LOOK THROUGH: LOOK_THROUGH
GO THROUGH: GO_THROUGH
LOCK WITH: RED_DOOR_KEY
UNLOCK WITH: RED_DOOR_KEY
THROW THROUGH: THROW_THROUGH
$09fast black river
west bank, east bank, bewitched gloomy place25525500present, full, liquidPUT IN: INTO_THE_RIVER
DROP IN: INTO_THE_RIVER
LOOK ACROSS: LOOK_ACROSS
SWIM: SWIM_BLACK_RIVER
$0Agoblins back doorinside goblins gate, outside goblins gate642558080presentOPEN: DO_OPEN
CLOSE: DO_CLOSE
STRIKE WITH: DO_STRIKE
LOOK THROUGH: LOOK_THROUGH
GO THROUGH: GO_THROUGH
THROW THROUGH: THROW_THROUGH
STRIKE WITH: DO_STRIKE
$0Bmountains side doorsidedoor, smooth straight passage25525500lockedCLOSE: DO_CLOSE
after CLOSE: SIDE_DOOR_CLOSED
UNLOCK WITH: SIDE_DOOR_KEY
after UNLOCK WITH: SIDE_DOOR_UNLOCKED
GO THROUGH: GO_THROUGH
LOOK THROUGH: LOOK_THROUGH
THROW THROUGH: THROW_THROUGH
$0Clarge trap doorelvenkings cellar, forestriver255255048presentOPEN: TRAP_DOOR_OPEN_CLOSE
CLOSE: TRAP_DOOR_OPEN_CLOSE
STRIKE WITH: DO_STRIKE
LOOK THROUGH: LOOK_THROUGH
GO THROUGH: GO_THROUGH
THROW THROUGH: THROW_THROUGH
after THROW THROUGH: BARREL_THROWN
$0Dmagic doorelvenkings great halls, levelled elvish clearing255255255255presentGO THROUGH: GO_THROUGH
LOOK THROUGH: LOOK_THROUGH
THROW THROUGH: THROW_THROUGH
EXAMINE: MAGIC_DOOR_EXAMINED
$0Eshort strong swordtrolls cave3464128present, fullSTRIKE WITH: DO_STRIKE
$0Fred keyelvenkings cellar, held by butler2222presentnone
$10valuable golden ringdark stuffy passage002550presentWEAR: WEAR_RING
TAKE OFF: TAKE_OFF_RING
$11goblins doorbig goblins cavern, goblins dungeon255255255255presentOPEN: GOBLINS_DOOR_OPENED
CLOSE: DO_CLOSE
GO THROUGH: GO_THROUGH
LOOK THROUGH: LOOK_THROUGH
THROW THROUGH: THROW_THROUGH
$12ropetrolls cave22325present, openTHROW ACROSS: THROW_ROPE_ACROSS
TIE TO: DO_TIE
PULL: PULL_ROPE
$13barrelelvenkings cellar3233232present, fullOPEN: DO_OPEN
CLOSE: DO_CLOSE
PUT IN: DO_PUT_IN
FILL WITH: DO_FILL
EMPTY: DO_EMPTY
JUMP ONTO: JUMP_ONTO_BARREL
CLIMB INTO: DO_CLIMB_INTO
STRIKE WITH: DO_STRIKE
$14wineelvenkings cellar, held by barrel31500present, liquidDRINK: DO_DRINK
after DRINK: WINE_DRUNK
$15waternowhere31500present, liquidDRINK: DO_DRINK
$16black waternowhere31500present, liquidDRINK: DRINK_BLACK_WATER
$17waterrunning river, forestriver, long lake, running river, great river, waterfall, deep dark lake, forestriver0500present, liquidDRINK: DRINK_WATER
$18black waterbewitched gloomy place, west bank, east bank31500present, liquidDRINK: DRINK_BLACK_WATER
$19bowlake town, held by bard531616presentSTRIKE WITH: DO_STRIKE
$1Astrong arrowlake town, held by bard211616presentSTRIKE WITH: DO_STRIKE
$1Bwindowgoblins dungeon, dark winding passage96255112112presentGO THROUGH: WINDOW_OTHERS
STRIKE WITH: WINDOW_OTHERS
OPEN: WINDOW_OPEN_CLOSE
CLOSE: WINDOW_OPEN_CLOSE
LOOK THROUGH: WINDOW_OTHERS
$1Ctorchbig goblins cavern, elvenkings great halls55128128present, fullnone
$1Dsandgoblins dungeon10110100presentDIG: DO_DIG
PUT IN: DO_PUT_IN
$1Etrap doorgoblins dungeon, held by sand255255128128present, lockedSTRIKE WITH: DO_STRIKE
UNLOCK WITH: NO_KEY_FITS
OPEN: DO_OPEN
$1Fgoblins cachegoblins dungeon, held by trap door25525500present, openPUT IN: DO_PUT_IN
TAKE OUT OF: DO_TAKE_OUT
$20heavy curtainbeorns house25525500presentOPEN: DO_OPEN
CLOSE: DO_CLOSE
$21large cupboardbeorns house, held by wall25525500presentOPEN: DO_OPEN
CLOSE: DO_CLOSE
PUT IN: DO_PUT_IN
TAKE OUT OF: DO_TAKE_OUT
STRIKE WITH: DO_STRIKE
$22foodbeorns house, held by large cupboard5510presentEAT: DO_EAT
$23valuable treasurelower halls323255presentnone
$24wallbeorns house, held by heavy curtain25525500present, opennone
$25wooden chesttunnel like hall6425500presentOPEN: DO_OPEN
CLOSE: DO_CLOSE
PUT IN: DO_PUT_IN
DROP IN: DO_PUT_IN
TAKE OUT OF: DO_TAKE_OUT
STRIKE WITH: DO_STRIKE
CLIMB INTO: DO_CLIMB_INTO
$26lunchnowhere5510presentEAT: DO_EAT
$27strong portcullisforestriver, long lake14425500presentGO THROUGH: GO_THROUGH
$28stoneempty place254254255255presentnone
$29wooden boateast bank6425500present, openPUT IN: DO_PUT_IN
DROP IN: DO_PUT_IN
TAKE OUT OF: DO_TAKE_OUT
STRIKE WITH: DO_STRIKE
CLIMB INTO: DO_CLIMB_INTO
after CLIMB INTO: BOAT_BOARDED
$2Afast riverforestriver, forestriver, long lake25525500present, full, liquidPUT IN: INTO_THE_RIVER
DROP IN: INTO_THE_RIVER
LOOK ACROSS: LOOK_ACROSS
SWIM: SWIM_RIVER
$2Bgolden keydeep misty valley0000presentnone